Index: webrtc/video_send_stream.h |
diff --git a/webrtc/video_send_stream.h b/webrtc/video_send_stream.h |
index 7ac4c3732464a21f0ed31554a8e4d556922c80f8..43283a55da1e959cd03c098c7e796376f3b9c6ed 100644 |
--- a/webrtc/video_send_stream.h |
+++ b/webrtc/video_send_stream.h |
@@ -129,8 +129,8 @@ class VideoSendStream { |
// See NackConfig for description. |
NackConfig nack; |
- // See FecConfig for description. |
- FecConfig fec; |
+ // See UlpfecConfig for description. |
+ UlpfecConfig ulpfec; |
// Settings for RTP retransmission payload format, see RFC 4588 for |
// details. |